@@ -1,11 +1,10 @@
-from finvizfinance.group.overview import Overview
-
 """
 .. module:: group.valuation
    :synopsis: group valuation table.
 
 .. moduleauthor:: Tianning Li <ltianningli@gmail.com>
 """
+from finvizfinance.group.overview import Overview
 
 
 class Valuation(Overview):
@@ -13,8 +12,4 @@ class Valuation(Overview):
     Getting information from the finviz group valuation page.
     """
 
-    def __init__(self):
-        """initiate module"""
-        self.BASE_URL = "https://finviz.com/groups.ashx?{group}&v=120"
-        self.url = self.BASE_URL.format(group="g=sector")
-        Overview._load_setting(self)
+    v_page = 120
