@@ -1,12 +1,11 @@
-import pandas as pd
-from finvizfinance.util import web_scrap, number_covert
-
 """
 .. module:: insider
    :synopsis: insider table.
 
 .. moduleauthor:: Tianning Li <ltianningli@gmail.com>
 """
+import pandas as pd
+from finvizfinance.util import web_scrap, number_covert
 
 INSIDER_URL = "https://finviz.com/insidertrading.ashx"
 
@@ -63,7 +62,7 @@ class Insider:
         Returns:
             df(pandas.DataFrame): insider information table
         """
-        insider_trader = self.soup.findAll("table")[4]
+        insider_trader = self.soup.find("table", class_="body-table w-full")
         rows = insider_trader.findAll("tr")
         table_header = [i.text.strip() for i in rows[0].findAll("td")] + [
             "SEC Form 4 Link"
