@@ -1,12 +1,11 @@
-from finvizfinance.screener.overview import Overview
-from finvizfinance.util import web_scrap, progress_bar
-
 """
 .. module:: screen.ticker
    :synopsis: screen ticker table.
 
 .. moduleauthor:: Tianning Li <ltianningli@gmail.com>
 """
+from finvizfinance.screener.overview import Overview
+from finvizfinance.util import web_scrap, progress_bar
 
 
 class Ticker(Overview):
@@ -14,31 +13,38 @@ class Ticker(Overview):
     Getting information from the finviz screener ticker page.
     """
 
-    def __init__(self):
-        """initiate module"""
-        self.BASE_URL = (
-            "https://finviz.com/screener.ashx?v=411{signal}{filter}&ft=4{ticker}"
-        )
-        self.url = self.BASE_URL.format(signal="", filter="", ticker="")
-        Overview._load_setting(self)
+    v_page = 411
 
     def _screener_helper(self, i, page, soup, tickers, limit):
-        table = soup.findAll("table")[19]
-        page_tickers = table.findAll("span")
+        td = soup.find("td", class_="screener-tickers")
+        page_tickers = td.findAll("span")
         if i == page - 1:
             page_tickers = page_tickers[: ((limit - 1) % 1000 + 1)]
         tickers = tickers + [i.text.split("\xa0")[1] for i in page_tickers]
         return tickers
 
-    def screener_view(self, limit=-1, verbose=1):
-        """Get screener table.
+    def screener_view(self, order="ticker", limit=-1, verbose=1, ascend=True):
+        """Get screener stocks.
 
         Args:
+            order(str): sort the list by the choice of order.
+            limit(int): set the top k stocks of the screener.
             verbose(int): choice of visual the progress. 1 for visualize progress.
+            ascend(bool): if True, the order is ascending.
         Returns:
             tickers(list): get all the tickers as list.
         """
-        soup = web_scrap(self.url)
+        url = self.url
+        if order != "ticker":
+            if order not in self.order_dict:
+                order_keys = list(self.order_dict.keys())
+                raise ValueError(
+                    "Invalid order '{}'. Possible order: {}".format(order, order_keys)
+                )
+            url = self.url + "&" + self.order_dict[order]
+        if not ascend:
+            url = url.replace("o=", "o=-")
+        soup = web_scrap(url)
         page = self._get_page(soup)
         if page == 0:
             if verbose == 1:
