@@ -1,14 +1,13 @@
-import sys
-import requests
-import pandas as pd
-from bs4 import BeautifulSoup
-
 """
 .. module:: util
    :synopsis: General function for the package.
 
 .. moduleauthor:: Tianning Li <ltianningli@gmail.com>
 """
+import sys
+import requests
+import pandas as pd
+from bs4 import BeautifulSoup
 
 headers = {
     "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_4) \
@@ -135,7 +134,7 @@ def scrap_function(url):
         df(pandas.DataFrame): performance table
     """
     soup = web_scrap(url)
-    table = soup.findAll("table")[3]
+    table = soup.find("table", class_="table-light")
     rows = table.findAll("tr")
     table_header = [i.text.strip() for i in rows[0].findAll("td")][1:]
     df = pd.DataFrame([], columns=table_header)
